@@ -27,7 +27,7 @@ from praw.compat import (HTTPCookieProcessor,  # pylint: disable-msg=E0611
                          urljoin)
 from praw.settings import CONFIG
 
-__version__ = '1.0.14'
+__version__ = '1.0.15'
 UA_STRING = '%%s PRAW/%s Python/%s %s' % (__version__,
                                           sys.version.split()[0],
                                           platform.platform(True))
@@ -54,6 +54,7 @@ class Config(object):  # pylint: disable-msg=R0903
                  'flairtemplate':       'api/flairtemplate/',
                  'friend':              'api/friend/',
                  'help':                'help/',
+                 'hide':                'api/hide/',
                  'inbox':               'message/inbox/',
                  'info':                'button_info/',
                  'login':               'api/login/',
@@ -90,12 +91,14 @@ class Config(object):  # pylint: disable-msg=R0903
                  'top':                 'top/',
                  'undistinguish':       'api/distinguish/no/',
                  'unfriend':            'api/unfriend/',
+                 'unhide':              'api/unhide/',
                  'unmarknsfw':          'api/unmarknsfw/',
                  'unread':              'message/unread/',
                  'unread_message':      'api/unread_message/',
                  'unsave':              'api/unsave/',
                  'user':                'user/%s/',
                  'user_about':          'user/%s/about/',
+                 'username_available':  'api/username_available/',
                  'vote':                'api/vote/'}
     SSL_PATHS = ('login', )
 
@@ -817,6 +820,19 @@ class Reddit(LoggedInExtension,  # pylint: disable-msg=R0904
         return self.get_content(self.config['info'], url_data=url_data,
                                 limit=limit)
 
+    def is_username_available(self, username):
+        """Return True if username is valid and available, otherwise False."""
+        url_data = {'user': username}
+        try:
+            result = self.request_json(self.config['username_available'],
+                                       url_data=url_data)
+        except errors.APIException as exception:
+            if exception.error_type == 'BAD_USERNAME':
+                result = False
+            else:
+                raise
+        return result
+
     def search(self, query, subreddit=None, sort=None, limit=0, *args,
                **kwargs):
         """Return submissions whose title contains the query phrase."""
